@@ -24,19 +24,17 @@ rlJournalStart
         rlRun "grep -E '^[[:digit:]]{2}:[[:digit:]]{2}:[[:digit:]]{2} ' $rlRun_LOG" 0
     rlPhaseEnd
 
-    # TODO: enable the test once --quiet starts silencing all kinds of logging
-    # See https://github.com/teemtee/tmt/issues/2106
-    # rlPhaseStartTest "Verify --quiet suppresses all logging"
-    #     rlRun "pushd data"
-    #
-    #     rlRun -s "tmt test show"
-    #     rlAssertGrep "warn: /tests: - 'non-existent-key' does not match any of the regexes" "$rlRun_LOG"
-    #
-    #     rlRun -s "tmt --quiet test show"
-    #     rlAssertNotGrep "warn: /tests: - 'non-existent-key' does not match any of the regexes" "$rlRun_LOG"
-    #
-    #     rlRun "popd"
-    # rlPhaseEnd
+    rlPhaseStartTest "Verify --quiet suppresses all logging"
+        rlRun "pushd data"
+
+        rlRun -s "tmt test show"
+        rlAssertGrep "warn: /tests: - 'non-existent-key' does not match any of the regexes" "$rlRun_LOG"
+
+        rlRun -s "tmt --quiet test show"
+        rlAssertNotGrep "warn: /tests: - 'non-existent-key' does not match any of the regexes" "$rlRun_LOG"
+
+        rlRun "popd"
+    rlPhaseEnd
 
     rlPhaseStartCleanup
     rlPhaseEnd
