@@ -1,6 +1,7 @@
-import os
+import urllib.parse
 
-from tmt.utils import DistGitHandler
+from tmt.utils import Path
+from tmt.utils.git import DistGitHandler
 
 MOCK_SOURCES_FILENAME = 'mock_sources'
 SERVER_PORT = 9000
@@ -17,9 +18,9 @@ class TestDistGit(DistGitHandler):
     usage_name = "TESTING"
     server = f"http://localhost:{SERVER_PORT}"
 
-    def url_and_name(self, cwd='.'):
-        with open(os.path.join(cwd, MOCK_SOURCES_FILENAME)) as f:
-            data = f.read()
+    def url_and_name(self, cwd=None):
+        cwd = cwd or Path.cwd()
+        data = (cwd / MOCK_SOURCES_FILENAME).read_text()
         for line in data.splitlines():
             split = line.split(' ', maxsplit=2)
             url = split[0]
@@ -27,4 +28,5 @@ class TestDistGit(DistGitHandler):
                 src_name = split[1]
             except IndexError:
                 src_name = url
-            yield (os.path.join(self.server, url), src_name)
+
+            yield (urllib.parse.urljoin(self.server, url), src_name)
