@@ -39,7 +39,7 @@ rlJournalStart
     rlPhaseStartSetup
         rlRun "tmp=\$(mktemp -d)" 0 "Create tmp directory"
         rlRun 'set -o pipefail'
-        rlRun "git clone https://src.fedoraproject.org/rpms/tmt.git $tmp/tmt"
+        rlWaitForCmd "git clone https://src.fedoraproject.org/rpms/tmt.git $tmp/tmt" -m 5 -d 10 -t 300 || rlDie "Unable to clone Fedora distgit repository"
         export CLONED_RPMS_TMT=$tmp/tmt
         rlRun "cp data/plans.fmf $CLONED_RPMS_TMT/plans"
         # Append existing TMT_PLUGINS content
@@ -321,7 +321,7 @@ EOF
         rlAssertNotExists $WORKDIR_TESTS/with-tmt-1
         rlAssertNotExists $WORKDIR_TESTS/rename-with-tmt-1.tgz
 
-        assert_tests $WORKDIR '"/top_test' '"/from-source'
+        assert_tests $WORKDIR '^/top_test$' '^/from-source$'
         rlRun 'popd'
     rlPhaseEnd
 
@@ -352,7 +352,7 @@ EOF
         # But not the tarball/patches..
         rlAssertNotExists $WORKDIR_TESTS/rename-with-tmt.tgz
 
-        assert_tests $WORKDIR '"/top_test' '"/with-tmt-1/tests/from-source'
+        assert_tests $WORKDIR '^/top_test$' '^/with-tmt-1/tests/from-source$'
         rlRun 'popd'
     rlPhaseEnd
 
@@ -430,7 +430,7 @@ EOF
         rlRun -s "tmt run --keep --id $WORKDIR --scratch plans --default \
              discover -vvv -ddd --how fmf --dist-git-source \
              --dist-git-type TESTING tests --name /tests/from-source provision -h local prepare"
-        assert_tests $WORKDIR '"/tests/from-source'
+        assert_tests $WORKDIR '^/tests/from-source$'
 
         # Source dir has everything available
         rlAssertExists $WORKDIR_SOURCE/with-tmt-1/tests/from-source.fmf
@@ -546,6 +546,41 @@ EOF
         rlAssertExists $WORKDIR_SOURCE/$MOCK_SOURCES_FILENAME
 
 
+        rlRun "popd"
+        rlRun "rm -rf $tmp"
+        rlRun "rm -rf $WORKDIR"
+    rlPhaseEnd
+
+    rlPhaseStartTest "dist-git-type: local"
+        rlRun "tmp=\$(mktemp -d)" 0 "Create tmp directory"
+        rlRun 'pushd $tmp'
+
+        echo "SHA512 (no-tmt-2.tgz) = 1234" > sources
+        rlRun "git init && tmt init"
+
+        cat <<EOF > plans.fmf
+discover:
+    how: shell
+    tests:
+    -   name: source is there
+        test: ls \$TMT_SOURCE_DIR/no-tmt-2.tgz
+    dist-git-source: true
+    dist-git-type: local
+    dist-git-download-only: true
+provision:
+    how: local
+execute:
+    how: tmt
+EOF
+
+        sed -e '/^BuildArch:/aSource0: no-tmt-2.tgz' $TEST_DIR/data/demo.spec > demo.spec
+        sed -e 's/package-src/no-tmt-2/' -i demo.spec
+
+        cp $SERVER_DIR/no-tmt-2.tgz .
+
+        WORKDIR=/var/tmp/tmt/XXX
+        rlRun "tmt run -vvv --id $WORKDIR --scratch"
+
         rlRun "popd"
         rlRun "rm -rf $tmp"
         rlRun "rm -rf $WORKDIR"
