@@ -3,12 +3,13 @@
 
 rlJournalStart
     rlPhaseStartSetup
-        rlRun "run=\$(mktemp -d)" 0 "Create run directory"
+        # use `/var/tmp` to persist the run dir during reboots, because `bootc` package manager used
+        rlRun "run=\$(mktemp -d -p /var/tmp)" 0 "Create run directory"
         rlRun "pushd data"
     rlPhaseEnd
 
     rlPhaseStartTest
-        if ! rlRun "tmt run -vvv --id $run"; then
+        if ! rlRun "TMT_SHOW_TRACEBACK=full tmt -vv run --id $run"; then
             rlFileSubmit $run/log.txt
         fi
     rlPhaseEnd
