@@ -67,26 +67,26 @@ rlJournalStart
         # Check the subresults get correctly saved in results.yaml
         rlRun "results_file=${run_dir}/plan/execute/results.yaml"
 
-        rlRun "yq -ey '.[] | select(.name == \"/test/shell/pass\") | .subresult' ${results_file} > subresults_pass.yaml"
+        rlRun "yq  -e '.[] | select(.name == \"/test/shell/pass\") | .subresult' ${results_file} > subresults_pass.yaml"
         rlAssertGrep "name: /pass-subtest/good0" "subresults_pass.yaml"
         rlAssertGrep "name: /pass-subtest/good1" "subresults_pass.yaml"
         rlAssertGrep "name: /pass-subtest/good2" "subresults_pass.yaml"
         rlAssertGrep "name: /pass-subtest/good3" "subresults_pass.yaml"
         rlAssertNotGrep "original-result: \(fail\|skip\|warn\)" "subresults_pass.yaml"
 
-        rlRun "yq -ey '.[] | select(.name == \"/test/shell/skip\") | .subresult' ${results_file} > subresults_skip.yaml"
+        rlRun "yq  -e '.[] | select(.name == \"/test/shell/skip\") | .subresult' ${results_file} > subresults_skip.yaml"
         rlAssertGrep "name: /skip-subtest/extra-pass" "subresults_skip.yaml"
         rlAssertGrep "name: /skip-subtest/extra-skip1" "subresults_skip.yaml"
         rlAssertGrep "name: /skip-subtest/extra-skip2" "subresults_skip.yaml"
 
-        rlRun "yq -ey '.[] | select(.name == \"/test/shell/fail\") | .subresult' ${results_file} > subresults_fail.yaml"
+        rlRun "yq  -e '.[] | select(.name == \"/test/shell/fail\") | .subresult' ${results_file} > subresults_fail.yaml"
         rlAssertGrep "name: /fail-subtest/good" "subresults_fail.yaml"
         rlAssertGrep "name: /fail-subtest/fail" "subresults_fail.yaml"
         rlAssertGrep "name: /fail-subtest/weird" "subresults_fail.yaml"
         rlAssertGrep "name: /fail-subtest/skip" "subresults_fail.yaml"
         rlAssertGrep "name: /fail-subtest/fail-rhts" "subresults_fail.yaml"
 
-        rlRun "yq -ey '.[] | select(.name == \"/test/beakerlib\") | .subresult' ${results_file} > subresults_beakerlib.yaml"
+        rlRun "yq  -e '.[] | select(.name == \"/test/beakerlib\") | .subresult' ${results_file} > subresults_beakerlib.yaml"
         rlAssertGrep "name: /phase-setup" "subresults_beakerlib.yaml"
         rlAssertGrep "name: /phase-test-pass" "subresults_beakerlib.yaml"
         rlAssertGrep "name: /phase-test-fail" "subresults_beakerlib.yaml"
@@ -95,7 +95,8 @@ rlJournalStart
         rlAssertGrep "name: /extra-tmt-report-result/bad" "subresults_beakerlib.yaml"
         rlAssertGrep "name: /extra-tmt-report-result/weird" "subresults_beakerlib.yaml"
         rlAssertGrep "name: /extra-tmt-report-result/skip" "subresults_beakerlib.yaml"
-        rlAssertGrep "name: /extra-rhts-report-result/bad" "subresults_beakerlib.yaml"
+        rlAssertGrep "name: /extra-rhts-report-result/bad-with-compat" "subresults_beakerlib.yaml"
+        rlAssertGrep "name: /extra-rhts-report-result/bad-without-compat" "subresults_beakerlib.yaml"
 
 
         # Check the subresults log entries are set in results.yaml
@@ -103,20 +104,21 @@ rlJournalStart
         rlAssertGrep "- data/.*/extra-tmt-report-result_bad/bkr_bad_log.txt$" "subresults_beakerlib.yaml"
         rlAssertGrep "- data/.*/extra-tmt-report-result_weird/bkr_weird_log.txt$" "subresults_beakerlib.yaml"
         rlAssertGrep "- data/.*/extra-tmt-report-result_skip/bkr_skip_log.txt$" "subresults_beakerlib.yaml"
-        rlAssertGrep "- data/.*/extra-rhts-report-result_bad/bkr_rhts_bad_log.txt$" "subresults_beakerlib.yaml"
+        rlAssertGrep "- data/.*/extra-rhts-report-result_bad-with-compat/resultoutputfile.log$" "subresults_beakerlib.yaml"
+        rlAssertGrep "- data/.*/extra-rhts-report-result_bad-without-compat/output.txt$" "subresults_beakerlib.yaml"
 
         rlAssertGrep "- data/.*/fail-subtest_good/good_log.txt$" "subresults_fail.yaml"
         rlAssertGrep "- data/.*/fail-subtest_fail/fail_log.txt$" "subresults_fail.yaml"
         rlAssertGrep "- data/.*/fail-subtest_weird/weird_log.txt$" "subresults_fail.yaml"
         rlAssertGrep "- data/.*/fail-subtest_skip/skip_log.txt$" "subresults_fail.yaml"
-        rlAssertGrep "- data/.*/fail-subtest_fail-rhts/fail-rhts_log.txt$" "subresults_fail.yaml"
+        rlAssertGrep "- data/.*/fail-subtest_fail-rhts/output.txt$" "subresults_fail.yaml"
 
-        rlAssertGrep "- data/.*/skip-subtest_extra-skip2/skip-rhts_log.txt$" "subresults_skip.yaml"
+        rlAssertGrep "- data/.*/skip-subtest_extra-skip2/output.txt$" "subresults_skip.yaml"
 
         rlAssertGrep "- data/.*/pass-subtest_good0/good0_log.txt$" "subresults_pass.yaml"
         rlAssertGrep "- data/.*/pass-subtest_good1/good1_log.txt$" "subresults_pass.yaml"
         rlAssertGrep "- data/.*/pass-subtest_good2/good2_log.txt$" "subresults_pass.yaml"
-        rlAssertGrep "- data/.*/pass-subtest_good3/good3_log.txt$" "subresults_pass.yaml"
+        rlAssertGrep "- data/.*/pass-subtest_good3/output.txt$" "subresults_pass.yaml"
 
 
         # Check the subresults log files actually exist
@@ -124,19 +126,20 @@ rlJournalStart
         rlAssertExists "$log_dir/shell/pass-3/data/pass-subtest_good0/good0_log.txt"
         rlAssertExists "$log_dir/shell/pass-3/data/pass-subtest_good1/good1_log.txt"
         rlAssertExists "$log_dir/shell/pass-3/data/pass-subtest_good2/good2_log.txt"
-        rlAssertExists "$log_dir/shell/pass-3/data/pass-subtest_good3/good3_log.txt"
+        rlAssertExists "$log_dir/shell/pass-3/data/pass-subtest_good3/output.txt"
 
         rlAssertExists "$log_dir/shell/fail-2/data/fail-subtest_fail/fail_log.txt"
         rlAssertExists "$log_dir/shell/fail-2/data/fail-subtest_good/good_log.txt"
         rlAssertExists "$log_dir/shell/fail-2/data/fail-subtest_skip/skip_log.txt"
         rlAssertExists "$log_dir/shell/fail-2/data/fail-subtest_weird/weird_log.txt"
-        rlAssertExists "$log_dir/shell/fail-2/data/fail-subtest_fail-rhts/fail-rhts_log.txt"
+        rlAssertExists "$log_dir/shell/fail-2/data/fail-subtest_fail-rhts/output.txt"
 
         rlAssertExists "$log_dir/beakerlib-1/data/extra-tmt-report-result_bad/bkr_bad_log.txt"
         rlAssertExists "$log_dir/beakerlib-1/data/extra-tmt-report-result_good/bkr_good_log.txt"
         rlAssertExists "$log_dir/beakerlib-1/data/extra-tmt-report-result_skip/bkr_skip_log.txt"
         rlAssertExists "$log_dir/beakerlib-1/data/extra-tmt-report-result_weird/bkr_weird_log.txt"
-        rlAssertExists "$log_dir/beakerlib-1/data/extra-rhts-report-result_bad/bkr_rhts_bad_log.txt"
+        rlAssertExists "$log_dir/beakerlib-1/data/extra-rhts-report-result_bad-with-compat/resultoutputfile.log"
+        rlAssertExists "$log_dir/beakerlib-1/data/extra-rhts-report-result_bad-without-compat/output.txt"
         rlAssertExists "$log_dir/beakerlib-1/journal.xml"
     rlPhaseEnd
 
