@@ -7,10 +7,10 @@ rlJournalStart
         rlRun "pushd $tmp"
         rlRun -s "tmt init -n"
         rlAssertNotExists ".fmf/version"
-        rlAssertGrep "Tree .* would be initialized." "${rlRun_LOG}"
+        rlAssertGrep "Would initialize the fmf tree root" "${rlRun_LOG}"
         rlRun -s "tmt init"
         rlAssertExists ".fmf/version"
-        rlAssertGrep "Tree .* initialized." "${rlRun_LOG}"
+        rlAssertGrep "Initialized the fmf tree root" "${rlRun_LOG}"
         rlRun "popd"
         rlRun "rm -r $tmp" 0 "Remove tmp directory"
     rlPhaseEnd
@@ -22,7 +22,7 @@ rlJournalStart
         rlAssertGrep "Plan directory .* would be created." "${rlRun_LOG}"
         rlAssertNotExists "plans/example.fmf"
         rlRun -s "tmt init -t mini"
-        rlAssertGrep "Tree .* initialized." "${rlRun_LOG}"
+        rlAssertGrep "Initialized the fmf tree root" "${rlRun_LOG}"
         rlAssertGrep "Applying template 'mini'." "${rlRun_LOG}"
         rlAssertGrep "Plan directory .* created." "${rlRun_LOG}"
         rlAssertExists "plans/example.fmf"
