@@ -3,7 +3,7 @@
 . /usr/share/beakerlib/beakerlib.sh || exit 1
 
 function assert_check_result () {
-    rlAssertEquals "$1" "avc:$2" "$(yq -r ".[] | select(.name == \"$4\")  | .check | .[] | select(.event == \"$3\") | \"\\(.name):\\(.result)\"" $results)"
+    rlAssertEquals "$1" "avc:$2" "$(yq ".[] | select(.name == \"$4\")  | .check | .[] | select(.event == \"$3\") | \"\\(.name):\\(.result)\"" $results)"
 }
 
 
@@ -28,28 +28,50 @@ rlJournalStart
         rlPhaseEnd
 
         rlPhaseStartTest "Test harmless AVC check with $PROVISION_HOW ($method method)"
-            rlRun "avc_log=$run/plan/execute/data/guest/default-0/avc/$method/harmless-2/checks/avc.txt"
+            rlRun "avc_log=$run/plan/execute/data/guest/default-0/avc/$method/harmless-3/checks/avc.txt"
             rlAssertExists "$avc_log"
             rlRun "cat $avc_log"
 
             assert_check_result "avc as an after-test should pass" "pass" "after-test" "/avc/$method/harmless"
 
             rlAssertGrep "<no matches>" "$avc_log"
-            rlAssertGrep "## mark" "$avc_log"
-            rlAssertGrep "## ausearch" "$avc_log"
+            rlAssertGrep "# --- mark" "$avc_log"
+            rlAssertGrep "# --- ausearch" "$avc_log"
+        rlPhaseEnd
+
+        rlPhaseStartTest "Test ignore-pattern key with $PROVISION_HOW ($method method)"
+            rlRun "avc_log=$run/plan/execute/data/guest/default-0/avc/$method/ignored-2/checks/avc.txt"
+            rlRun "failures=$run/plan/execute/data/guest/default-0/avc/$method/ignored-2/checks/failures.yaml"
+            rlAssertExists "$avc_log"
+            rlAssertExists "$failures"
+            rlRun "cat $avc_log"
+
+            assert_check_result "avc as an after-test should pass" "pass" "after-test" "/avc/$method/ignored"
+
+            rlRun "yq -e 'tag == \"!!seq\" and length == 0' $failures" 0 "No failures should be recorded"
+
+            # AVC denial should still be present in the log
+            rlAssertGrep "avc:  denied" "$avc_log"
+            rlAssertGrep "path=/root/passwd.log" "$avc_log"
+            rlAssertGrep "# --- mark" "$avc_log"
+            rlAssertGrep "# --- ausearch" "$avc_log"
         rlPhaseEnd
 
         rlPhaseStartTest "Test nasty AVC check with $PROVISION_HOW ($method method)"
             rlRun "avc_log=$run/plan/execute/data/guest/default-0/avc/$method/nasty-1/checks/avc.txt"
+            rlRun "failures=$run/plan/execute/data/guest/default-0/avc/$method/nasty-1/checks/failures.yaml"
             rlAssertExists "$avc_log"
+            rlAssertExists "$failures"
             rlRun "cat $avc_log"
 
             assert_check_result "avc as an after-test should report AVC denials" "fail" "after-test" "/avc/$method/nasty"
 
+            rlAssertGrep "avc:  denied" "$failures"
+
             rlAssertGrep "avc:  denied" "$avc_log"
             rlAssertGrep "path=/root/passwd.log" "$avc_log"
-            rlAssertGrep "## mark" "$avc_log"
-            rlAssertGrep "## ausearch" "$avc_log"
+            rlAssertGrep "# --- mark" "$avc_log"
+            rlAssertGrep "# --- ausearch" "$avc_log"
         rlPhaseEnd
     done
 
