@@ -148,16 +148,16 @@ rlJournalStart
 
     rlPhaseStartTest "Test whether 'tmt', 'tests' and 'show' accept verbosity option"
         rlRun -s "tmt    tests    show    /tests/full"
-        rlAssertNotGrep "fmf-id url" $rlRun_LOG
+        rlAssertNotGrep "fmf-id" $rlRun_LOG
 
         rlRun -s "tmt    tests    show -v /tests/full"
-        rlAssertGrep "fmf-id url" $rlRun_LOG
+        rlAssertGrep "fmf-id" $rlRun_LOG
 
         rlRun -s "tmt    tests -v show    /tests/full"
-        rlAssertGrep "fmf-id url" $rlRun_LOG
+        rlAssertGrep "fmf-id" $rlRun_LOG
 
         rlRun -s "tmt -v tests    show    /tests/full"
-        rlAssertGrep "fmf-id url" $rlRun_LOG
+        rlAssertGrep "fmf-id" $rlRun_LOG
     rlPhaseEnd
 
     rlPhaseStartCleanup
