@@ -8,6 +8,7 @@ from tmt.hardware import (
     Hardware,
     Operator,
     _parse_cpu,
+    _parse_device,
     _parse_disk,
     _parse_hostname,
     _parse_iommu,
@@ -53,10 +54,15 @@ def test_maximal_constraint(root_logger: Logger) -> None:
     assert result.to_mrack() == {
         'and': [
             {
-                'pool': {
-                    '_op': '!=',
-                    '_value': 'foo.*',
-                },
+                'and': [
+                    {
+                        'pool': {
+                            '_op': '!=',
+                            '_value': 'foo.*',
+                        },
+                    },
+                    {},
+                ],
             },
             {},
             {'and': [{}, {}]},
@@ -119,10 +125,25 @@ def test_maximal_constraint(root_logger: Logger) -> None:
             },
             {
                 'and': [
+                    {
+                        'device': {
+                            '_vendor_id': '97',
+                            '_op': '>',
+                        },
+                    },
+                    {
+                        'device': {
+                            '_device_id': '79',
+                            '_op': '==',
+                        },
+                    },
                     {},
-                    {},
-                    {},
-                    {},
+                    {
+                        'device': {
+                            '_description': '%Thunderbolt%',
+                            '_op': 'like',
+                        },
+                    },
                     {
                         'key_value': {
                             '_key': 'MODULE',
@@ -197,6 +218,7 @@ def test_maximal_constraint(root_logger: Logger) -> None:
                             },
                         },
                     },
+                    {},
                 ]
             },
             {
@@ -581,3 +603,81 @@ def test_or_constraint(root_logger: Logger) -> None:
             },
         ],
     }
+
+
+def test_device_device(root_logger: Logger) -> None:
+    result = _CONSTRAINT_TRANSFORMERS['device.device'](
+        _parse_device({'device': '1645'}), root_logger
+    )
+
+    assert result.to_mrack() == {'device': {'_op': '==', '_device_id': '1645'}}
+
+    result = _CONSTRAINT_TRANSFORMERS['device.device'](
+        _parse_device({'device': '!= 1645'}), root_logger
+    )
+
+    assert result.to_mrack() == {'device': {'_op': '!=', '_device_id': '1645'}}
+
+    result = _CONSTRAINT_TRANSFORMERS['device.device'](
+        _parse_device({'device': '> 1000'}), root_logger
+    )
+
+    assert result.to_mrack() == {'device': {'_op': '>', '_device_id': '1000'}}
+
+    result = _CONSTRAINT_TRANSFORMERS['device.device'](
+        _parse_device({'device': '< 2000'}), root_logger
+    )
+
+    assert result.to_mrack() == {'device': {'_op': '<', '_device_id': '2000'}}
+
+
+def test_device_vendor(root_logger: Logger) -> None:
+    result = _CONSTRAINT_TRANSFORMERS['device.vendor'](
+        _parse_device({'vendor': '0x10de'}), root_logger
+    )
+
+    assert result.to_mrack() == {'device': {'_op': '==', '_vendor_id': '4318'}}
+
+    result = _CONSTRAINT_TRANSFORMERS['device.vendor'](
+        _parse_device({'vendor': '!= 0x10de'}), root_logger
+    )
+
+    assert result.to_mrack() == {'device': {'_op': '!=', '_vendor_id': '4318'}}
+
+    result = _CONSTRAINT_TRANSFORMERS['device.vendor'](
+        _parse_device({'vendor': '> 4318'}), root_logger
+    )
+
+    assert result.to_mrack() == {'device': {'_op': '>', '_vendor_id': '4318'}}
+
+    result = _CONSTRAINT_TRANSFORMERS['device.vendor'](
+        _parse_device({'vendor': '< 32902'}), root_logger
+    )
+
+    assert result.to_mrack() == {'device': {'_op': '<', '_vendor_id': '32902'}}
+
+
+def test_device_device_name(root_logger: Logger) -> None:
+    result = _CONSTRAINT_TRANSFORMERS['device.device_name'](
+        _parse_device({'device-name': 'Genoa CCP'}), root_logger
+    )
+
+    assert result.to_mrack() == {'device': {'_op': '==', '_description': 'Genoa CCP'}}
+
+    result = _CONSTRAINT_TRANSFORMERS['device.device_name'](
+        _parse_device({'device-name': '!= Genoa CCP'}), root_logger
+    )
+
+    assert result.to_mrack() == {'device': {'_op': '!=', '_description': 'Genoa CCP'}}
+
+    result = _CONSTRAINT_TRANSFORMERS['device.device_name'](
+        _parse_device({'device-name': '~ Genoa.*'}), root_logger
+    )
+
+    assert result.to_mrack() == {'device': {'_op': 'like', '_description': 'Genoa%'}}
+
+    result = _CONSTRAINT_TRANSFORMERS['device.device_name'](
+        _parse_device({'device-name': '!~ Genoa.*'}), root_logger
+    )
+
+    assert result.to_mrack() == {'not': {'device': {'_op': 'like', '_description': 'Genoa%'}}}
