@@ -5,7 +5,9 @@ from tmt.steps.prepare.install import InstallBase
 
 
 def test_debuginfo(root_logger):
-    """ Check debuginfo package parsing """
+    """
+    Check debuginfo package parsing
+    """
 
     parent = MagicMock()
     guest = MagicMock()
@@ -20,18 +22,19 @@ def test_debuginfo(root_logger):
             # Debuginfo packages
             DependencySimple("grep-debuginfo"),
             DependencySimple("elfutils-debuginfod-debuginfo"),
-            ],
+        ],
         directories=[],
         exclude=[],
         logger=root_logger,
-        guest=guest)
+        guest=guest,
+    )
 
     assert install.packages == [
         "wget",
         "debuginfo-something",
         "elfutils-debuginfod",
-        ]
+    ]
     assert install.debuginfo_packages == [
         "grep",
         "elfutils-debuginfod",
-        ]
+    ]
