@@ -16,6 +16,10 @@ import tmt.cli.trying
             {'image_and_how': ('fedora@virtual',), 'arch': 'aarch64'},
             {'image': 'fedora', 'how': 'virtual', 'arch': 'aarch64'},
         ),
+        (
+            {'image_and_how': ('@local',), 'arch': None},
+            {'how': 'local'},
+        ),
         (
             {'image_and_how': (), 'arch': 'aarch64'},
             {'arch': 'aarch64'},
