@@ -998,14 +998,14 @@ def test_fmf_id(local_git_repo, root_logger, git_ref):
 class TestGitAdd:
     @classmethod
     def test_not_in_repository(cls, nested_file: tuple[Path, Path, Path], root_logger):
-        top_dir, sub_dir, file = nested_file
+        _, sub_dir, _ = nested_file
 
         with pytest.raises(GeneralError, match=r"Failed to add path .* to git index."):
             git_add(path=sub_dir, logger=root_logger)
 
     @classmethod
     def test_in_repository(cls, nested_file: tuple[Path, Path, Path], root_logger):
-        top_dir, sub_dir, file = nested_file
+        top_dir, sub_dir, _ = nested_file
         run(ShellScript('git init').to_shell_command(), cwd=top_dir)
 
         git_add(path=sub_dir, logger=root_logger)
@@ -1764,11 +1764,9 @@ def test_render_command_report_output():
                 ),
             )
         )
-        == f"""## foo
-
-# /bar/baz
-
-# exit code: finished successfully
+        == f"""# --- foo
+# Command: /bar/baz
+# Finished successfully
 
 # stdout (1 lines)
 # {delimiter}
@@ -1779,6 +1777,7 @@ This is some stdout
 # {delimiter}
 This is some stderr
 # {delimiter}
+
 """
     )
 
@@ -1800,11 +1799,9 @@ def test_render_command_report_exception():
                 ),
             )
         )
-        == f"""## foo
-
-# /bar/baz
-
-# exit code: 1
+        == f"""# --- foo
+# Command: /bar/baz
+# Exit code: 1
 
 # stdout (1 lines)
 # {delimiter}
@@ -1815,6 +1812,7 @@ This is some stdout
 # {delimiter}
 This is some stderr
 # {delimiter}
+
 """
     )
 
@@ -1823,6 +1821,7 @@ def test_render_command_report_minimal():
     print(list(tmt.utils.render_command_report(label='foo')))
     assert (
         '\n'.join(tmt.utils.render_command_report(label='foo'))
-        == """## foo
+        == """# --- foo
+# Finished successfully
 """
     )
