@@ -1,13 +1,15 @@
+import dataclasses
 import re
-from typing import TYPE_CHECKING
+from typing import TYPE_CHECKING, Optional
 
-import tmt.base
 import tmt.log
 import tmt.result
 import tmt.steps.execute
+import tmt.steps.scripts
 import tmt.utils
 from tmt.frameworks import TestFramework, provides_framework
-from tmt.result import ResultOutcome
+from tmt.result import ResultOutcome, save_failures
+from tmt.steps.provision import TransferOptions
 from tmt.utils import Environment, EnvVarValue, GeneralError, Path
 
 if TYPE_CHECKING:
@@ -18,6 +20,48 @@ if TYPE_CHECKING:
 BEAKERLIB_REPORT_RESULT_COMMAND = 'rhts-report-result'
 
 
+def _extract_failures(invocation: 'TestInvocation', log_path: Path) -> list[str]:
+    try:
+        log = invocation.phase.step.plan.execute.read(log_path)
+    except tmt.utils.FileError:
+        return []
+
+    # Filter beakerlib style logs in the following way:
+    # 1. Reverse the log string by lines
+    # 2. Search for each FAIL and extract every associated line.
+    # 3. For failed phases also extract phase name so the log is easier to understand
+    # 4. Reverse extracted lines back into correct order.
+    if re.search(':: \\[   FAIL   \\] ::', log):  # dumb check for a beakerlib log
+        copy_line = False
+        copy_phase_name = False
+        failure_log: list[str] = []
+        # we will be processing log lines in a reversed order
+        iterator = iter(reversed(log.split("\n")))
+        for line in iterator:
+            # found FAIL enables log extraction
+            if re.search(':: \\[   FAIL   \\] ::', line):
+                copy_line = True
+                copy_phase_name = True
+            # BEGIN of rlRun block or previous command or beginning of a test section
+            # disables extraction
+            elif re.search('(:: \\[.{10}\\] ::|[:]{80})', line):
+                copy_line = False
+            # extract line from the log
+            if copy_line:
+                failure_log.append(line)
+            # Add beakerlib phase name to a failure log, in order to properly match the phase
+            # name we need to do this in two steps.
+            if copy_phase_name and re.search('[:]{80}', line):
+                # read the next line containing phase name
+                line = next(iterator)
+                failure_log.append(f'\n{line}')
+                copy_phase_name = False
+        # reverse extracted lines to restore previous order
+        failure_log.reverse()
+        return ['\n'.join(failure_log).strip()]
+    return []
+
+
 @provides_framework('beakerlib')
 class Beakerlib(TestFramework):
     @classmethod
@@ -44,8 +88,8 @@ class Beakerlib(TestFramework):
         # will *accept* the third positional argument as a `logfile`.
         # - https://github.com/teemtee/tmt/blob/e7cf41d1fe5a4dcbb3270758586f41313e9462ec/tmt/steps/execute/scripts/tmt-report-result#L101
         if BEAKERLIB_REPORT_RESULT_COMMAND not in [
-            tmt.steps.execute.TMT_REPORT_RESULT_SCRIPT.source_filename,
-            *tmt.steps.execute.TMT_REPORT_RESULT_SCRIPT.aliases,
+            tmt.steps.scripts.TMT_REPORT_RESULT_SCRIPT.source_filename,
+            *tmt.steps.scripts.TMT_REPORT_RESULT_SCRIPT.aliases,
         ]:
             raise GeneralError(
                 "Beakerlib framework requires the "
@@ -58,7 +102,7 @@ class Beakerlib(TestFramework):
                 'BEAKERLIB_DIR': EnvVarValue(invocation.path),
                 'BEAKERLIB_COMMAND_SUBMIT_LOG': EnvVarValue(
                     invocation.guest.scripts_path
-                    / tmt.steps.execute.TMT_FILE_SUBMIT_SCRIPT.source_filename
+                    / tmt.steps.scripts.TMT_FILE_SUBMIT_SCRIPT.source_filename
                 ),
                 # The command in this variable gets called with every
                 # `rlPhaseEnd` call in beakerlib.
@@ -73,8 +117,20 @@ class Beakerlib(TestFramework):
         )
 
     @classmethod
-    def get_pull_options(cls, invocation: 'TestInvocation', logger: tmt.log.Logger) -> list[str]:
-        return ['--exclude', str(invocation.path / "backup*")]
+    def get_pull_options(
+        cls,
+        invocation: 'TestInvocation',
+        options: Optional['TransferOptions'],
+        logger: tmt.log.Logger,
+    ) -> 'TransferOptions':
+        # Do not pull beakerlib backups
+        return (
+            dataclasses.replace(
+                options, exclude=[*options.exclude, str(invocation.path / "backup*")]
+            )
+            if options
+            else TransferOptions(exclude=[str(invocation.path / "backup*")])
+        )
 
     @classmethod
     def extract_results(
@@ -91,10 +147,28 @@ class Beakerlib(TestFramework):
 
         # Initialize data, prepare log paths
         note: list[str] = []
-        log: list[Path] = []
-        for filename in [tmt.steps.execute.TEST_OUTPUT_FILENAME, 'journal.txt']:
-            if (invocation.path / filename).is_file():
-                log.append(invocation.relative_path / filename)
+
+        # BeakerLib automatically submits 'journal.xml' and it gets collected as a log, so
+        # it is omitted here to avoid logging it twice.
+        log: list[Path] = [
+            invocation.relative_path / filename
+            for filename in [tmt.steps.execute.TEST_OUTPUT_FILENAME, 'journal.txt']
+            if (invocation.path / filename).is_file()
+        ]
+
+        # Check for failures in the beakerlib log
+        if (invocation.path / tmt.steps.execute.TEST_OUTPUT_FILENAME).exists():
+            # Save potential failures to the file
+            log.append(
+                save_failures(
+                    invocation,
+                    invocation.path,
+                    _extract_failures(
+                        invocation,
+                        invocation.relative_path / tmt.steps.execute.TEST_OUTPUT_FILENAME,
+                    ),
+                )
+            )
 
         # Check beakerlib log for the result
         beakerlib_results_filepath = invocation.path / 'TestResults'
@@ -148,12 +222,8 @@ class Beakerlib(TestFramework):
         # Check if it was killed by timeout (set by tmt executor)
         actual_result = ResultOutcome.ERROR
         if invocation.return_code == tmt.utils.ProcessExitCodes.TIMEOUT:
-            note.append('timeout')
             invocation.phase.timeout_hint(invocation)
 
-        elif tmt.utils.ProcessExitCodes.is_pidfile(invocation.return_code):
-            note.append('pidfile locking')
-
         # Test results should be in complete state
         elif state != 'complete':
             note.append(f"beakerlib: State '{state}'")
