@@ -120,8 +120,10 @@ def _debug_level_from_global_envvar() -> int:
     try:
         return int(raw_value)
 
-    except ValueError:
-        raise tmt.utils.GeneralError(f"Invalid debug level '{raw_value}', use an integer.")
+    except ValueError as error:
+        raise tmt.utils.GeneralError(
+            f"Invalid debug level '{raw_value}', use an integer."
+        ) from error
 
 
 def decide_colorization(no_color: bool, force_color: bool) -> tuple[bool, bool]:
@@ -445,6 +447,17 @@ class LoggingFunction(Protocol):
         pass
 
 
+class Print(Protocol):
+    def __call__(
+        self,
+        text: Optional[str] = None,
+        color: 'tmt.utils.themes.Style' = None,
+        file: Optional[TextIO] = None,
+        nl: bool = True,
+    ) -> None:
+        pass
+
+
 class Logger:
     """
     A logging entry point, representing a certain level of verbosity and handlers.
@@ -502,6 +515,24 @@ class Logger:
 
         self._decolorize_output = create_decolorizer(apply_colors_output)
 
+    def __getstate__(self) -> dict[str, Any]:
+        """
+        Helper function for pickling.
+        """
+        state = self.__dict__.copy()
+        current_count = next(state["_child_id_counter"])
+        state["_child_id_counter"] = current_count
+        self._child_id_counter = itertools.count(current_count)
+        return state
+
+    def __setstate__(self, state: dict[str, Any]) -> None:
+        """
+        Helper function for pickling.
+        """
+        current_count: int = state["_child_id_counter"]
+        state["_child_id_counter"] = itertools.count(current_count)
+        self.__dict__.update(state)
+
     def __repr__(self) -> str:
         return (
             f'<Logger:'
@@ -688,13 +719,13 @@ class Logger:
             try:
                 self.topics.add(Topic(topic_spec))
 
-            except Exception:
+            except Exception as error:
                 import tmt.utils
 
                 raise tmt.utils.GeneralError(
                     f'Logging topic "{topic_spec}" is invalid.'
                     f" Possible choices are {', '.join(topic.value for topic in Topic)}"
-                )
+                ) from error
 
         return self
 
@@ -787,13 +818,16 @@ class Logger:
 
     def print(
         self,
-        text: str,
+        text: Optional[str] = None,
         color: 'tmt.utils.themes.Style' = None,
         file: Optional[TextIO] = None,
+        nl: bool = True,
     ) -> None:
+        text = text or ''
         file = file or sys.stdout
+        end = '\n' if nl else ''
 
-        print(self.print_format(text, color=color), file=file)
+        print(self.print_format(text, color=color), file=file, end=end)
 
     def info(
         self,
