@@ -20,6 +20,8 @@ from tmt.utils import (
     ShellScript,
 )
 
+LOCALHOST_BOOTC_IMAGE_PREFIX = "localhost/tmt"
+
 
 class BootcEngine(PackageManagerEngine):
     containerfile_directives: list[str]
@@ -51,11 +53,14 @@ class BootcEngine(PackageManagerEngine):
         """
         Prepare installation command for bootc
         """
+        assert self.guest.facts.sudo_prefix is not None  # Narrow type
 
-        if self.guest.facts.is_superuser is False:
-            return (Command('sudo', 'bootc'), Command(''))
+        command = Command('bootc')
 
-        return (Command('bootc'), Command(''))
+        if self.guest.facts.sudo_prefix:
+            command = Command(self.guest.facts.sudo_prefix, 'bootc')
+
+        return command, Command('')
 
     def _get_current_bootc_image(self) -> str:
         """Get the current bootc image running on the system"""
@@ -70,7 +75,7 @@ class BootcEngine(PackageManagerEngine):
         try:
             image_status = json.loads(output.stdout)
         except json.JSONDecodeError as error:
-            raise tmt.utils.PrepareError(f"Failed to parse bootc status JSON: {error}")
+            raise tmt.utils.PrepareError("Failed to parse bootc status JSON.") from error
 
         if not image_status:
             raise tmt.utils.PrepareError("Failed to get current bootc status: empty JSON.")
@@ -93,10 +98,15 @@ class BootcEngine(PackageManagerEngine):
 
             return base_image
         except KeyError as error:
-            raise tmt.utils.PrepareError(f"Failed to extract bootc image info: missing {error}")
+            raise tmt.utils.PrepareError("Failed to extract bootc image info.") from error
 
     def _get_base_containerfile_directives(self) -> list[str]:
-        return [f'FROM containers-storage:{self._get_current_bootc_image()}']
+        bootc_image = self._get_current_bootc_image()
+
+        if bootc_image.startswith(LOCALHOST_BOOTC_IMAGE_PREFIX):
+            return [f'FROM containers-storage:{bootc_image}']
+
+        return [f'FROM {bootc_image}']
 
     def check_presence(self, *installables: Installable) -> ShellScript:
         return self.aux_engine.check_presence(*installables)
@@ -142,7 +152,9 @@ class BootcEngine(PackageManagerEngine):
         return script
 
 
-@provides_package_manager('bootc')
+# ignore[type-arg]: TypeVar in package manager registry annotations is
+# puzzling for type checkers. And not a good idea in general, probably.
+@provides_package_manager('bootc')  # type: ignore[arg-type]
 class Bootc(PackageManager[BootcEngine]):
     NAME = 'bootc'
 
@@ -191,7 +203,7 @@ class Bootc(PackageManager[BootcEngine]):
             self.debug("No Containerfile directives to build container image, skipping build.")
             return
 
-        image_tag = f"localhost/tmt/bootc/{uuid.uuid4()}"
+        image_tag = f"{LOCALHOST_BOOTC_IMAGE_PREFIX}/bootc/{uuid.uuid4()}"
 
         # Write the final Containerfile
         with self.guest.mkdtemp() as containerfile_dir:
@@ -201,8 +213,6 @@ class Bootc(PackageManager[BootcEngine]):
 
             base_image = self.engine._get_current_bootc_image()
 
-            sudo = 'sudo' if self.guest.facts.is_superuser is False else ''
-
             try:
                 # First try if image is available in container registries.
                 # Next try the local container storage.
@@ -214,7 +224,7 @@ class Bootc(PackageManager[BootcEngine]):
                 # https://github.com/bootc-dev/bootc/issues/1259 for more information.
                 self.guest.execute(
                     ShellScript(
-                        f'{sudo} {tmt.utils.DEFAULT_SHELL} -c "('
+                        f'{self.guest.facts.sudo_prefix} {tmt.utils.DEFAULT_SHELL} -c "('
                         f'  ( podman pull {base_image} || podman pull containers-storage:{base_image} )'  # noqa: E501
                         f'  || bootc image copy-to-storage --target {base_image}'
                         ')"'
@@ -232,7 +242,7 @@ class Bootc(PackageManager[BootcEngine]):
 
                 self.guest.execute(
                     ShellScript(
-                        f'{sudo} podman build -t {image_tag} -f {containerfile_path} {self.guest.parent.workdir}'  # noqa: E501
+                        f'{self.guest.facts.sudo_prefix} podman build -t {image_tag} -f {containerfile_path} {self.guest.step_workdir}'  # noqa: E501
                     )
                 )
 
@@ -265,7 +275,7 @@ class Bootc(PackageManager[BootcEngine]):
         presence = self.check_presence(*installables)
 
         missing_installables: set[Installable] = {
-            installable for installable in installables if not presence[installable]
+            installable for installable, present in presence.items() if not present
         }
 
         if missing_installables:
