@@ -19,12 +19,12 @@ class RpmOstreeEngine(PackageManagerEngine):
         Prepare installation command for rpm-ostree
         """
 
-        command = Command()
+        assert self.guest.facts.sudo_prefix is not None  # Narrow type
 
-        if self.guest.facts.is_superuser is False:
-            command += Command('sudo')
+        command = Command('rpm-ostree')
 
-        command += Command('rpm-ostree')
+        if self.guest.facts.sudo_prefix:
+            command = Command(self.guest.facts.sudo_prefix, 'rpm-ostree')
 
         options = Command('--apply-live', '--idempotent', '--allow-inactive', '--assumeyes')
 
@@ -113,7 +113,9 @@ class RpmOstreeEngine(PackageManagerEngine):
         raise GeneralError("rpm-ostree does not support debuginfo packages.")
 
 
-@provides_package_manager('rpm-ostree')
+# ignore[type-arg]: TypeVar in package manager registry annotations is
+# puzzling for type checkers. And not a good idea in general, probably.
+@provides_package_manager('rpm-ostree')  # type: ignore[arg-type]
 class RpmOstree(PackageManager[RpmOstreeEngine]):
     NAME = 'rpm-ostree'
 
