@@ -1,7 +1,7 @@
+import abc
 from collections.abc import Iterator
 from typing import TYPE_CHECKING, Any, Callable
 
-import tmt.log
 import tmt.utils
 from tmt.plugins import PluginRegistry
 
@@ -11,29 +11,6 @@ if TYPE_CHECKING:
     from tmt.steps.discover import TestOrigin
 
 
-PlanShaperClass = type['PlanShaper']
-
-
-_PLAN_SHAPER_PLUGIN_REGISTRY: PluginRegistry[PlanShaperClass] = PluginRegistry('plan_shapers')
-
-
-def provides_plan_shaper(shaper: str) -> Callable[[PlanShaperClass], PlanShaperClass]:
-    """
-    A decorator for registering plan shaper plugins.
-
-    Decorate a plan shaper plugin class to register a plan shaper.
-    """
-
-    def _provides_plan_shaper(plan_shaper_cls: PlanShaperClass) -> PlanShaperClass:
-        _PLAN_SHAPER_PLUGIN_REGISTRY.register_plugin(
-            plugin_id=shaper, plugin=plan_shaper_cls, logger=tmt.log.Logger.get_bootstrap_logger()
-        )
-
-        return plan_shaper_cls
-
-    return _provides_plan_shaper
-
-
 class PlanShaper(tmt.utils.Common):
     """
     A base class for plan shaper plugins.
@@ -43,6 +20,7 @@ class PlanShaper(tmt.utils.Common):
         super().__init__(*args, **kwargs)
 
     @classmethod
+    @abc.abstractmethod
     def run_options(cls) -> list['ClickOptionDecoratorType']:
         """
         Return additional options for ``tmt run``.
@@ -51,6 +29,7 @@ class PlanShaper(tmt.utils.Common):
         raise NotImplementedError
 
     @classmethod
+    @abc.abstractmethod
     def check(cls, plan: 'Plan', tests: list['TestOrigin']) -> bool:
         """
         Check whether this shaper should be applied to the given plan.
@@ -61,6 +40,7 @@ class PlanShaper(tmt.utils.Common):
         raise NotImplementedError
 
     @classmethod
+    @abc.abstractmethod
     def apply(cls, plan: 'Plan', tests: list['TestOrigin']) -> Iterator['Plan']:
         """
         Apply the shaper to a given plan and a set of tests.
@@ -69,3 +49,11 @@ class PlanShaper(tmt.utils.Common):
         """
 
         raise NotImplementedError
+
+
+_PLAN_SHAPER_PLUGIN_REGISTRY: PluginRegistry[type[PlanShaper]] = PluginRegistry('plan_shapers')
+
+provides_plan_shaper: Callable[
+    [str],
+    Callable[[type[PlanShaper]], type[PlanShaper]],
+] = _PLAN_SHAPER_PLUGIN_REGISTRY.create_decorator()
