@@ -2,7 +2,7 @@ import contextlib
 import glob
 import re
 import shutil
-from typing import Any, Optional, cast
+from typing import Any, Literal, Optional, cast
 
 import fmf
 
@@ -16,6 +16,7 @@ import tmt.steps.discover
 import tmt.utils
 import tmt.utils.filesystem
 import tmt.utils.git
+import tmt.utils.url
 from tmt.base import _RawAdjustRule
 from tmt.container import container, field
 from tmt.steps.prepare.distgit import insert_to_prepare_step
@@ -42,13 +43,23 @@ class DiscoverFmfStepData(tmt.steps.discover.DiscoverStepData):
     url: Optional[str] = field(
         default=cast(Optional[str], None),
         option=('-u', '--url'),
-        metavar='REPOSITORY',
+        metavar='URL',
         help="""
-            Git repository containing the metadata tree.
+            External URL containing the metadata tree.
             Current git repository used by default.
+            See ``url-content-type`` key for details on what content is accepted.
             """,
     )
 
+    url_content_type: Literal["git", "archive"] = field(
+        default="git",
+        option="--url-content-type",
+        help="""
+            How to handle the ``url`` key.
+            """,
+        choices=("git", "archive"),
+    )
+
     ref: Optional[str] = field(
         default=cast(Optional[str], None),
         option=('-r', '--ref'),
@@ -112,6 +123,7 @@ class DiscoverFmfStepData(tmt.steps.discover.DiscoverStepData):
             and target. Relation part can be omitted to match all
             relations.
              """,
+        normalize=tmt.utils.normalize_string_list,
     )
 
     filter: list[str] = field(
@@ -310,6 +322,20 @@ class DiscoverFmf(tmt.steps.discover.DiscoverPlugin[DiscoverFmfStepData]):
 
     If no ``ref`` is provided, the default branch from the origin is used.
 
+    Archive
+    ^^^^^^^
+
+    By default ``url`` is treated as a git url to be cloned, but you can set
+    ``url-content-type`` to ``archive`` to instead treat it as an archive url
+    and download and extract it. For example:
+
+    .. code-block:: yaml
+
+        discover:
+            how: fmf
+            url: https://github.com/teemtee/tmt/archive/refs/heads/main.tar.gz
+            url-content-type: archive
+            path: /tmt-main/fmf/root
 
     Dist Git
     ^^^^^^^^
@@ -398,6 +424,16 @@ class DiscoverFmf(tmt.steps.discover.DiscoverPlugin[DiscoverFmfStepData]):
             how: fmf
             link: verifies:.*issue/850$
 
+    Multiple links can be provided as well:
+
+    .. code-block:: yaml
+
+        discover:
+            how: fmf
+            link:
+              - verifies:.*issue/850$
+              - verifies:.*issue/1374$
+
     Advanced Filter
     ^^^^^^^^^^^^^^^
 
@@ -516,9 +552,8 @@ class DiscoverFmf(tmt.steps.discover.DiscoverPlugin[DiscoverFmfStepData]):
         path = Path(cast(str, self.get('path'))) if self.get('path') else None
         # Save the test directory so that others can reference it
         ref = self.get('ref')
-        assert self.workdir is not None
-        self.testdir = self.workdir / 'tests'
-        sourcedir = self.workdir / 'source'
+        self.testdir = self.phase_workdir / 'tests'
+        sourcedir = self.phase_workdir / 'source'
         dist_git_source = self.get('dist-git-source', False)
         dist_git_merge = self.get('dist-git-merge', False)
 
@@ -537,17 +572,29 @@ class DiscoverFmf(tmt.steps.discover.DiscoverPlugin[DiscoverFmfStepData]):
         # prompt to ignore possibly missing or private repositories
         if url:
             self.info('url', url, 'green')
-            self.debug(f"Clone '{url}' to '{self.testdir}'.")
-            # Shallow clone to speed up testing and
-            # minimize data transfers if ref is not provided
-            tmt.utils.git.git_clone(
-                url=url,
-                destination=self.testdir,
-                shallow=ref is None,
-                env=Environment({"GIT_ASKPASS": EnvVarValue("echo")}),
-                logger=self._logger,
-            )
-            git_root = self.testdir
+            if self.data.url_content_type == "git":
+                self.debug(f"Clone '{url}' to '{self.testdir}'.")
+                # Shallow clone to speed up testing and
+                # minimize data transfers if ref is not provided
+                tmt.utils.git.git_clone(
+                    url=url,
+                    destination=self.testdir,
+                    shallow=ref is None,
+                    env=Environment({"GIT_ASKPASS": EnvVarValue("echo")}),
+                    logger=self._logger,
+                )
+                git_root = self.testdir
+            elif self.data.url_content_type == "archive":
+                archive_path = tmt.utils.url.download(
+                    url, self.phase_workdir, logger=logger or self._logger
+                )
+                self.debug(f"Extracting archive to '{self.testdir}'.")
+                shutil.unpack_archive(archive_path, self.testdir)
+                git_root = self.testdir
+            else:
+                raise ValueError(
+                    f"url-content-type has unsupported value: {self.data.url_content_type}"
+                )
         # Copy git repository root to workdir
         else:
             if path is not None:
@@ -563,10 +610,12 @@ class DiscoverFmf(tmt.steps.discover.DiscoverPlugin[DiscoverFmfStepData]):
                 # Ensure we're in a git repo when extracting dist-git sources
                 try:
                     git_root = self.get_git_root(Path(self.step.plan.node.root))
-                except tmt.utils.RunError:
+                except tmt.utils.RunError as error:
                     assert self.step.plan.my_run is not None  # narrow type
                     assert self.step.plan.my_run.tree is not None  # narrow type
-                    raise tmt.utils.DiscoverError(f"{self.step.plan.node.root} is not a git repo")
+                    raise tmt.utils.DiscoverError(
+                        f"{self.step.plan.node.root} is not a git repo"
+                    ) from error
             else:
                 if fmf_root is None:
                     raise tmt.utils.DiscoverError("No metadata found in the current directory.")
@@ -603,7 +652,7 @@ class DiscoverFmf(tmt.steps.discover.DiscoverPlugin[DiscoverFmfStepData]):
                 plan=self.step.plan,
             )
         except tmt.utils.FileError as error:
-            raise tmt.utils.DiscoverError(str(error))
+            raise tmt.utils.DiscoverError("Could not resolve dynamic reference") from error
 
         # Checkout revision if requested
         if ref:
@@ -866,8 +915,7 @@ class DiscoverFmf(tmt.steps.discover.DiscoverPlugin[DiscoverFmfStepData]):
         dist_git_merge = self.get('dist-git-merge', False)
         dist_git_remove_fmf_root = self.get('dist-git-remove-fmf-root', False)
 
-        assert self.workdir is not None  # narrow type
-        sourcedir = self.workdir / 'source'
+        sourcedir = self.phase_workdir / 'source'
 
         # '/' means everything which was extracted from the srpm and do not flatten
         # glob otherwise
@@ -876,10 +924,10 @@ class DiscoverFmf(tmt.steps.discover.DiscoverPlugin[DiscoverFmfStepData]):
                 dist_git_extract = Path(
                     glob.glob(str(sourcedir / dist_git_extract.lstrip('/')))[0]
                 )
-            except IndexError:
+            except IndexError as error:
                 raise tmt.utils.DiscoverError(
                     f"Couldn't glob '{dist_git_extract}' within extracted sources."
-                )
+                ) from error
         if dist_git_init:
             if dist_git_extract == '/' or not dist_git_extract:
                 dist_git_extract = '/'
