@@ -13,11 +13,11 @@ import tmt.utils
 import tmt.utils.signals
 import tmt.utils.wait
 from tmt.container import container, field
+from tmt.steps.provision import RebootMode
 from tmt.utils import (
     Command,
     ProvisionError,
     ShellScript,
-    UpdatableMessage,
     dict_to_yaml,
     normalize_string_dict,
     retry_session,
@@ -72,6 +72,15 @@ SUPPORTED_LOG_TYPES = [
     'console:dump/url',
     'console:interactive/url',
     'sys.log:dump/url',
+    'flasher-debug:dump/url',
+    'flasher-debug:dump/blob',
+    'flasher-event:dump/url',
+    'flasher-event:dump/blob',
+    'anaconda.log:dump/blob',
+    'storage.log:dump/blob',
+    'program.log:dump/blob',
+    'packaging.log:dump/blob',
+    'ks.cfg:dump/blob',
 ]
 
 
@@ -345,6 +354,7 @@ class ArtemisAPI:
                 504,  # Gateway Timeout
             ),
             timeout=guest.api_timeout,
+            logger=guest._logger,
         )
 
     def query(
@@ -538,13 +548,12 @@ class GuestArtemis(tmt.GuestSsh):
                 f"API version '{self.api_version}' does not support watchdog specification."
             )
 
-        # TODO: snapshots
         # TODO: spot instance
 
         if self.post_install_script:
             if tmt.utils.is_url(self.post_install_script):
                 try:
-                    with retry_session() as session:
+                    with retry_session(logger=self._logger) as session:
                         response = session.get(self.post_install_script)
 
                     if not response.ok:
@@ -579,42 +588,47 @@ class GuestArtemis(tmt.GuestSsh):
 
         self.info('guestname', self.guestname, 'green')
 
-        with UpdatableMessage('state', indent_level=self._level()) as progress_message:
+        # Track the previous state to only log when it changes
+        previous_state = None
 
-            def get_new_state() -> GuestInspectType:
-                response = self.api.inspect(f'/guests/{self.guestname}')
+        def get_new_state() -> GuestInspectType:
+            nonlocal previous_state
+            response = self.api.inspect(f'/guests/{self.guestname}')
 
-                if response.status_code != 200:
-                    raise ArtemisProvisionError('Failed to create', response=response)
+            if response.status_code != 200:
+                raise ArtemisProvisionError('Failed to create', response=response)
 
-                current = cast(GuestInspectType, response.json())
-                state = current['state']
-                state_color = GUEST_STATE_COLORS.get(state, GUEST_STATE_COLOR_DEFAULT)
+            current = cast(GuestInspectType, response.json())
+            state = current['state']
+            state_color = GUEST_STATE_COLORS.get(state, GUEST_STATE_COLOR_DEFAULT)
 
-                progress_message.update(state, color=state_color)
+            # Log state change on new line when it changes
+            if state != previous_state:
+                self.info('state', state, color=state_color)
+                previous_state = state
 
-                if state == 'error':
-                    raise ArtemisProvisionError('Failed to create, provisioning failed.')
+            if state == 'error':
+                raise ArtemisProvisionError('Failed to create, provisioning failed.')
 
-                if state == 'ready':
-                    return current
+            if state == 'ready':
+                return current
 
-                raise tmt.utils.wait.WaitingIncompleteError
+            raise tmt.utils.wait.WaitingIncompleteError
 
-            try:
-                guest_info = Waiting(
-                    Deadline.from_seconds(self.provision_timeout), tick=self.provision_tick
-                ).wait(get_new_state, self._logger)
+        try:
+            guest_info = Waiting(
+                Deadline.from_seconds(self.provision_timeout), tick=self.provision_tick
+            ).wait(get_new_state, self._logger)
 
-            except tmt.utils.wait.WaitingTimedOutError:
-                # The provisioning chain has been already started, make sure we
-                # remove the guest.
-                self.remove()
+        except tmt.utils.wait.WaitingTimedOutError as error:
+            # The provisioning chain has been already started, make sure we
+            # remove the guest.
+            self.remove()
 
-                raise ArtemisProvisionError(
-                    f'Failed to provision in the given amount '
-                    f'of time (--provision-timeout={self.provision_timeout}).'
-                )
+            raise ArtemisProvisionError(
+                f'Failed to provision in the given amount '
+                f'of time (--provision-timeout={self.provision_timeout}).'
+            ) from error
 
         self.primary_address = self.topology_address = guest_info['address']
 
@@ -630,6 +644,13 @@ class GuestArtemis(tmt.GuestSsh):
         if self.guestname is None or self.primary_address is None:
             self._create()
 
+        self.guest_logs += [
+            GuestLogArtemis(
+                name=log_type.replace(':', '_').replace('/', '_'), guest=self, log_type=log_type
+            )
+            for log_type in self.log_type
+        ]
+
         self.verbose('primary address', self.primary_address, 'green')
         self.verbose('topology address', self.topology_address, 'green')
 
@@ -648,9 +669,6 @@ class GuestArtemis(tmt.GuestSsh):
         if response.status_code == 404:
             self.info('guest', 'no longer exists', 'red')
 
-        elif response.status_code == 409:
-            self.info('guest', 'has existing snapshots', 'red')
-
         elif response.ok:
             self.info('guest', 'has been removed', 'green')
 
@@ -661,28 +679,13 @@ class GuestArtemis(tmt.GuestSsh):
 
     def reboot(
         self,
-        hard: bool = False,
+        mode: RebootMode = RebootMode.SOFT,
         command: Optional[Union[Command, ShellScript]] = None,
         waiting: Optional[Waiting] = None,
     ) -> bool:
-        """
-        Reboot the guest, and wait for the guest to recover.
-
-        :param hard: if set, force the reboot. This may result in a loss of
-            data. The default of ``False`` will attempt a graceful reboot.
-        :param command: a command to run on the guest to trigger the reboot.
-        :param timeout: amount of time in which the guest must become available
-            again.
-        :param tick: how many seconds to wait between two consecutive attempts
-            of contacting the guest.
-        :param tick_increase: a multiplier applied to ``tick`` after every
-            attempt.
-        :returns: ``True`` if the reboot succeeded, ``False`` otherwise.
-        """
-
         waiting = waiting or tmt.steps.provision.default_reboot_waiting()
 
-        if hard:
+        if mode == RebootMode.HARD:
             if self.guestname is None:
                 raise ArtemisProvisionError("Cannot reboot - guest does not exist")
 
@@ -696,13 +699,13 @@ class GuestArtemis(tmt.GuestSsh):
                     raise ArtemisProvisionError('Failed to reboot guest', response=response)
 
             return self.perform_reboot(
+                mode,
                 trigger_reboot,
                 waiting,
-                fetch_boot_time=False,
             )
 
         return super().reboot(
-            hard=False,
+            mode=mode,
             command=command,
             waiting=waiting,
         )
@@ -817,3 +820,65 @@ class ProvisionArtemis(tmt.steps.provision.ProvisionPlugin[ProvisionArtemisData]
         )
         self._guest.start()
         self._guest.setup()
+
+
+class GuestLogBlobType(TypedDict):
+    ctime: str
+    content: str
+
+
+@container
+class GuestLogArtemis(tmt.steps.provision.GuestLog):
+    guest: GuestArtemis
+    log_type: str
+
+    def fetch(self, logger: tmt.log.Logger) -> Optional[str]:
+        """
+        Fetch and return content of a log.
+
+        :returns: content of the log, or ``None`` if the log cannot be retrieved.
+        """
+        if self.guest.guestname is None:
+            logger.warning("Failed to fetch log - guest does not exist.")
+            return None
+
+        response = self.guest.api.inspect(f'/guests/{self.guest.guestname}/logs/{self.log_type}')
+
+        if response.status_code == 404:
+            return None
+
+        if response.status_code != 200:
+            logger.warning(
+                f"Failed to fetch log '{self.log_type}': {response.status_code} {response.reason}"
+            )
+            return None
+
+        log_data = response.json()
+        if self.log_type.endswith('/url'):
+            return self._fetch_url(log_data, logger)
+        return self._fetch_blob(log_data)
+
+    @staticmethod
+    def _fetch_url(log_data: dict[str, Any], logger: tmt.log.Logger) -> Optional[str]:
+        url = log_data.get('url')
+        if url is None:
+            return None
+        try:
+            return tmt.utils.get_url_content(str(url), logger)
+        except Exception as error:
+            tmt.utils.show_exception_as_warning(
+                exception=error,
+                message=f"Failed to fetch '{url}' log.",
+                logger=logger,
+            )
+        return None
+
+    @staticmethod
+    def _fetch_blob(log_data: dict[str, Any]) -> Optional[str]:
+        blobs = cast(list[GuestLogBlobType], log_data.get('blobs', []))
+        if not blobs:
+            return None
+        return "\n\n".join(
+            f"{blob['ctime']}\n{blob['content']}"
+            for blob in sorted(blobs, key=lambda blob: blob['ctime'])
+        )
