@@ -1,3 +1,4 @@
+import abc
 import asyncio
 import dataclasses
 import datetime
@@ -25,12 +26,12 @@ import tmt.utils.signals
 import tmt.utils.wait
 from tmt.config.models.hardware import MrackTranslation
 from tmt.container import container, field, simple_field
+from tmt.steps.provision import RebootMode
 from tmt.utils import (
     Command,
     Path,
     ProvisionError,
     ShellScript,
-    UpdatableMessage,
 )
 from tmt.utils.templates import render_template
 from tmt.utils.wait import Deadline, Waiting
@@ -142,7 +143,7 @@ def operator_to_beaker_op(operator: tmt.hardware.Operator, value: str) -> tuple[
 # to accept, but with strict type annotations; the layer is aware of how to convert
 # its components into dictionaries.
 @container
-class MrackBaseHWElement:
+class MrackBaseHWElement(abc.ABC):
     """
     Base for Mrack hardware requirement elements
     """
@@ -151,6 +152,7 @@ class MrackBaseHWElement:
     # types.
     name: str
 
+    @abc.abstractmethod
     def to_mrack(self) -> dict[str, Any]:
         """
         Convert the element to Mrack-compatible dictionary tree
@@ -197,6 +199,18 @@ class MrackHWKeyValue(MrackHWElement):
         self.attributes = {'_key': name, '_op': operator, '_value': value}
 
 
+@container(init=False)
+class MrackHWDeviceElement(MrackHWElement):
+    """
+    An element for device with op and value attributes
+    """
+
+    def __init__(self, operator: str, value: str, attribute_name: str = 'value') -> None:
+        super().__init__('device')
+
+        self.attributes = {'_op': operator, f'_{attribute_name}': value}
+
+
 BeakerizedConstraint = Union[MrackBaseHWElement, dict[str, Any]]
 
 
@@ -547,6 +561,80 @@ def _transform_device_driver(
     return _transform_driver_helper("MODULE", constraint, logger)
 
 
+@transforms
+def _transform_device_device(
+    constraint: tmt.hardware.IntegerConstraint, logger: tmt.log.Logger
+) -> MrackBaseHWElement:
+    """
+    Transform device.device constraint to Beaker's Devices/Device_id filter.
+
+    This maps to Beaker's Devices/Device_id field which allows filtering by
+    device ID, for example device_id="1645".
+    """
+    beaker_operator, actual_value, negate = operator_to_beaker_op(
+        constraint.operator, str(constraint.value)
+    )
+
+    # Create device element with device_id attribute
+    device_element = MrackHWDeviceElement(
+        beaker_operator, actual_value, attribute_name='device_id'
+    )
+
+    if negate:
+        return MrackHWNotGroup(children=[device_element])
+
+    return device_element
+
+
+@transforms
+def _transform_device_vendor(
+    constraint: tmt.hardware.IntegerConstraint, logger: tmt.log.Logger
+) -> MrackBaseHWElement:
+    """
+    Transform device.vendor constraint to Beaker's Devices/Vendor_id filter.
+
+    This maps to Beaker's Devices/Vendor_id field which allows filtering by
+    vendor ID, for example vendor_id="0x10de" for Nvidia.
+    """
+    beaker_operator, actual_value, negate = operator_to_beaker_op(
+        constraint.operator, str(constraint.value)
+    )
+
+    # Create device element with vendor_id attribute
+    device_element = MrackHWDeviceElement(
+        beaker_operator, actual_value, attribute_name='vendor_id'
+    )
+
+    if negate:
+        return MrackHWNotGroup(children=[device_element])
+
+    return device_element
+
+
+@transforms
+def _transform_device_device_name(
+    constraint: tmt.hardware.TextConstraint, logger: tmt.log.Logger
+) -> MrackBaseHWElement:
+    """
+    Transform device.device-name constraint to Beaker's Devices/Description filter.
+
+    This maps to Beaker's Devices/Description field which allows filtering by
+    device description/name, for example 'Genoa CCP' device.
+    """
+    beaker_operator, actual_value, negate = operator_to_beaker_op(
+        constraint.operator, constraint.value
+    )
+
+    device_element = MrackHWDeviceElement(
+        beaker_operator, actual_value, attribute_name='description'
+    )
+
+    if negate:
+        return MrackHWNotGroup(children=[device_element])
+
+    return device_element
+
+
 @transforms
 def _transform_disk_size(
     constraint: tmt.hardware.SizeConstraint, logger: tmt.log.Logger
@@ -642,9 +730,7 @@ def _transform_tpm_version(
 def _transform_virtualization_is_virtualized(
     constraint: tmt.hardware.FlagConstraint, logger: tmt.log.Logger
 ) -> BeakerizedConstraint:
-    beaker_operator, actual_value, _ = operator_to_beaker_op(
-        constraint.operator, str(constraint.value)
-    )
+    operator_to_beaker_op(constraint.operator, str(constraint.value))
 
     test = (constraint.operator, constraint.value)
 
@@ -842,7 +928,7 @@ def constraint_to_beaker_filter(
         constraint, logger
     ) or _translate_constraint_by_transformer(constraint, logger)
 
-    if not transformed:
+    if not transformed and constraint.name != 'beaker.panic_watchdog':
         # Make sure user is aware constraint would have no effect.
         logger.warning(f"Hardware requirement '{constraint.printable_name}' will have no effect.")
     return transformed
@@ -899,8 +985,10 @@ def import_and_load_mrack_deps(mrack_log: str, logger: tmt.log.Logger) -> None:
 
             providers.register(BEAKER, BeakerProvider)
 
-        except ImportError:
-            raise ProvisionError("Install 'tmt+provision-beaker' to provision using this method.")
+        except ImportError as error:
+            raise ProvisionError(
+                "Install 'tmt+provision-beaker' to provision using this method."
+            ) from error
 
     # ignore the misc because mrack sources are not typed and result into
     # error: Class cannot subclass "BeakerTransformer" (has type "Any")
@@ -931,6 +1019,20 @@ def import_and_load_mrack_deps(mrack_log: str, logger: tmt.log.Logger) -> None:
             # See https://github.com/teemtee/tmt/issues/3442
             return {'hostRequires': MrackHWAndGroup(children=[transformed]).to_mrack()}
 
+        def _requires_panic_watchdog(self, constraint: tmt.hardware.BaseConstraint) -> bool:
+            """
+            Check if any of the constraints are beaker panic-watchdog with the value True
+            """
+            if isinstance(constraint, tmt.hardware.FlagConstraint):
+                return constraint.name == 'beaker.panic_watchdog' and constraint.value
+
+            if isinstance(constraint, (tmt.hardware.And, tmt.hardware.Or)):
+                return any(
+                    self._requires_panic_watchdog(child) for child in constraint.constraints
+                )
+
+            return False
+
         def create_host_requirement(self, host: CreateJobParameters) -> dict[str, Any]:
             """
             Create single input for Beaker provisioner
@@ -938,9 +1040,17 @@ def import_and_load_mrack_deps(mrack_log: str, logger: tmt.log.Logger) -> None:
 
             req: dict[str, Any] = super().create_host_requirement(host.to_mrack())
 
+            # set beaker-watchdog to ignore kernel panic by default
+            panic_watchdog = False
+
             if host.hardware and host.hardware.constraint:
                 req.update(self._translate_tmt_hw(host.hardware))
 
+                panic_watchdog = self._requires_panic_watchdog(host.hardware.constraint)
+
+            if not panic_watchdog:
+                req['watchdog'] = {'panic': 'ignore'}
+
             if host.beaker_job_owner:
                 req['job_owner'] = host.beaker_job_owner
 
@@ -1199,11 +1309,12 @@ class CreateJobParameters:
     whiteboard: Optional[str]
     beaker_job_owner: Optional[str]
     public_key: list[str]
-    group: Optional[str]
+    beaker_job_group: Optional[str]
     bootc_credentials: Optional[dict[str, Any]]
     bootc_image_url: Optional[str]
     bootc: bool
     bootc_check_system_url: Optional[str]
+    group: str = 'linux'
 
     def to_mrack(self) -> dict[str, Any]:
         data = dataclasses.asdict(self)
@@ -1225,6 +1336,8 @@ class CreateJobParameters:
                 data['beaker']['ks_append'] = kickstart
         if self.public_key:
             data['beaker']['pubkeys'] = self.public_key
+        if self.beaker_job_group:
+            data['beaker']['beaker_job_group'] = self.beaker_job_group
 
         return data
 
@@ -1265,23 +1378,19 @@ class BeakerAPI:
 
         try:
             init_mrack_global_context(str(mrack_config))
-        except mrack.errors.ConfigError as mrack_conf_err:
-            raise ProvisionError(mrack_conf_err)
+        except mrack.errors.ConfigError as error:
+            raise ProvisionError("mrack configuration error at provision.") from error
 
         self._mrack_transformer = TmtBeakerTransformer()
         try:
             await self._mrack_transformer.init(global_context.PROV_CONFIG, {})
 
-        except NotAuthenticatedError as kinit_err:
-            raise ProvisionError(kinit_err) from kinit_err
-        except AttributeError as hub_err:
-            raise ProvisionError(
-                f"Can not use current kerberos ticket to authenticate: {hub_err}"
-            ) from hub_err
-        except FileNotFoundError as missing_conf_err:
-            raise ProvisionError(
-                f"Configuration file missing: {missing_conf_err.filename}"
-            ) from missing_conf_err
+        except NotAuthenticatedError as error:
+            raise ProvisionError("Authentication error.") from error
+        except AttributeError as error:
+            raise ProvisionError("Can not use current kerberos ticket to authenticate.") from error
+        except FileNotFoundError as error:
+            raise ProvisionError("Configuration file missing.") from error
         except Exception as e:
             raise ProvisionError("Failed to initialize mrack transformer.") from e
 
@@ -1457,7 +1566,7 @@ class GuestBeaker(tmt.steps.provision.GuestSsh):
             whiteboard=self.whiteboard or tmt_name,
             beaker_job_owner=self.beaker_job_owner,
             public_key=self.public_key,
-            group=self.beaker_job_group,
+            beaker_job_group=self.beaker_job_group,
             bootc_credentials=self._bootc_registry_credentials if self.bootc else None,
             bootc_image_url=self.bootc_image_url,
             bootc=self.bootc,
@@ -1524,53 +1633,58 @@ class GuestBeaker(tmt.steps.provision.GuestSsh):
 
         self.info('job id', self.job_id, 'green')
 
-        with UpdatableMessage("status", indent_level=self._level()) as progress_message:
+        # Track the previous state to only log when it changes
+        previous_state = None
 
-            def get_new_state() -> GuestInspectType:
-                response = self.api.inspect()
+        def get_new_state() -> GuestInspectType:
+            nonlocal previous_state
+            response = self.api.inspect()
 
-                if response["status"] == "Aborted":
-                    raise ProvisionError(
-                        f"Failed to create, unhandled API response '{response['status']}'."
-                    )
-
-                current = cast(GuestInspectType, response)
-                state = current["status"]
-                state_color = GUEST_STATE_COLORS.get(state, GUEST_STATE_COLOR_DEFAULT)
-
-                progress_message.update(state, color=state_color)
-
-                if state in {"Error, Aborted", "Cancelled"}:
-                    raise ProvisionError('Failed to create, provisioning failed.')
-
-                if state == 'Reserved':
-                    for key in response.get('logs', []):
-                        self.guest_logs.append(
-                            GuestLogBeaker(key.replace('.log', ''), self, response["logs"][key])
-                        )
-                    # console.log contains dmesg, and accessible even when the system is dead.
-                    if response.get('logs', []).get('console.log'):
-                        self.guest_logs.append(
-                            GuestLogBeaker('dmesg', self, response.get('logs').get('console.log'))
-                        )
-                    else:
-                        self.warn('No console.log available.')
-                    return current
-
-                raise tmt.utils.wait.WaitingIncompleteError
-
-            try:
-                guest_info = Waiting(
-                    Deadline.from_seconds(self.provision_timeout), tick=self.provision_tick
-                ).wait(get_new_state, self._logger)
-
-            except tmt.utils.wait.WaitingTimedOutError:
-                response = self.api.delete()
+            if response["status"] == "Aborted":
                 raise ProvisionError(
-                    f'Failed to provision in the given amount '
-                    f'of time (--provision-timeout={self.provision_timeout}).'
+                    f"Failed to create, unhandled API response '{response['status']}'."
                 )
 
+            current = cast(GuestInspectType, response)
+            state = current["status"]
+            state_color = GUEST_STATE_COLORS.get(state, GUEST_STATE_COLOR_DEFAULT)
+
+            # Log state change on new line when it changes
+            if state != previous_state:
+                self.info('status', state, color=state_color)
+                previous_state = state
+
+            if state in {"Error, Aborted", "Cancelled"}:
+                raise ProvisionError('Failed to create, provisioning failed.')
+
+            if state == 'Reserved':
+                for key in response.get('logs', []):
+                    self.guest_logs.append(
+                        GuestLogBeaker(key.replace('.log', ''), self, response["logs"][key])
+                    )
+                # console.log contains dmesg, and accessible even when the system is dead.
+                if response.get('logs', []).get('console.log'):
+                    self.guest_logs.append(
+                        GuestLogBeaker('dmesg', self, response.get('logs').get('console.log'))
+                    )
+                else:
+                    self.warn('No console.log available.')
+                return current
+
+            raise tmt.utils.wait.WaitingIncompleteError
+
+        try:
+            guest_info = Waiting(
+                Deadline.from_seconds(self.provision_timeout), tick=self.provision_tick
+            ).wait(get_new_state, self._logger)
+
+        except tmt.utils.wait.WaitingTimedOutError as error:
+            response = self.api.delete()
+            raise ProvisionError(
+                f'Failed to provision in the given amount '
+                f'of time (--provision-timeout={self.provision_timeout}).'
+            ) from error
+
         self.primary_address = self.topology_address = guest_info['system']
 
         self.verbose('primary address', self.primary_address, 'green')
@@ -1590,52 +1704,40 @@ class GuestBeaker(tmt.steps.provision.GuestSsh):
 
     def reboot(
         self,
-        hard: bool = False,
+        mode: RebootMode = RebootMode.SOFT,
         command: Optional[Union[Command, ShellScript]] = None,
         waiting: Optional[Waiting] = None,
     ) -> bool:
         """
         Reboot the guest, and wait for the guest to recover.
 
-        .. note::
+        Plugin will use ``bkr system-power`` command to trigger to
+        perform the :py:attr:`RebootMode.HARD` reboot. Unlike ``command``,
+        this command would be executed on the runner, **not** on the guest.
 
-           Custom reboot command can be used only in combination with a
-           soft reboot. If both ``hard`` and ``command`` are set, a hard
-           reboot will be requested, and ``command`` will be ignored.
-
-        :param hard: if set, force the reboot. This may result in a loss
-            of data. The default of ``False`` will attempt a graceful
-            reboot.
-
-            Plugin will use ``bkr system-power`` command to trigger the
-            hard reboot. Unlike ``command``, this command would be
-            executed on the runner, **not** on the guest.
+        :param mode: which boot mode to perform.
         :param command: a command to run on the guest to trigger the
-            reboot. If ``hard`` is also set, ``command`` is ignored.
-        :param timeout: amount of time in which the guest must become available
-            again.
-        :param tick: how many seconds to wait between two consecutive attempts
-            of contacting the guest.
-        :param tick_increase: a multiplier applied to ``tick`` after every
-            attempt.
+            reboot. Only usable when mode is not
+            :py:attr:`RebootMode.HARD`.
+        :param waiting: deadline for the reboot.
         :returns: ``True`` if the reboot succeeded, ``False`` otherwise.
         """
 
         waiting = waiting or tmt.steps.provision.default_reboot_waiting()
 
-        if hard:
+        if mode == RebootMode.HARD:
             self.debug("Hard reboot using the reboot command 'bkr system-power --action reboot'.")
 
             reboot_script = ShellScript(f'bkr system-power --action reboot {self.primary_address}')
 
             return self.perform_reboot(
+                mode,
                 lambda: self._run_guest_command(reboot_script.to_shell_command()),
                 waiting,
-                fetch_boot_time=False,
             )
 
         return super().reboot(
-            hard=False,
+            mode=mode,
             command=command,
             waiting=waiting,
         )
@@ -1810,7 +1912,7 @@ class GuestLogBeaker(tmt.steps.provision.GuestLog):
         :returns: content of the log, or ``None`` if the log cannot be retrieved.
         """
         try:
-            return tmt.utils.get_url_content(self.url)
+            return tmt.utils.get_url_content(self.url, logger)
         except Exception as error:
             tmt.utils.show_exception_as_warning(
                 exception=error,
